summaryrefslogtreecommitdiff
path: root/idlc/inc/idlc/astdeclaration.hxx
diff options
context:
space:
mode:
authorJuergen Schmidt <jsc@openoffice.org>2001-05-18 14:38:10 +0000
committerJuergen Schmidt <jsc@openoffice.org>2001-05-18 14:38:10 +0000
commitf3097d7b52b481bfec4e6235c9396738ea3aa9f2 (patch)
treead68b788aa60bc47b6b18056a54c75db07618e38 /idlc/inc/idlc/astdeclaration.hxx
parent465b869e784fa0a3641f36a1d65d29605447d3bd (diff)
#87233# insert singleton
Diffstat (limited to 'idlc/inc/idlc/astdeclaration.hxx')
-rw-r--r--idlc/inc/idlc/astdeclaration.hxx7
1 files changed, 4 insertions, 3 deletions
diff --git a/idlc/inc/idlc/astdeclaration.hxx b/idlc/inc/idlc/astdeclaration.hxx
index bc887c4e1aa0..7716e31b9361 100644
--- a/idlc/inc/idlc/astdeclaration.hxx
+++ b/idlc/inc/idlc/astdeclaration.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: astdeclaration.hxx,v $
*
- * $Revision: 1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: jsc $ $Date: 2001-03-15 12:23:01 $
+ * last change: $Author: jsc $ $Date: 2001-05-18 15:33:49 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -101,7 +101,8 @@ enum NodeType
NT_array, // Denotes an IDL array
NT_sequence, // Denotes an IDL sequence
NT_typedef, // Denotes a typedef
- NT_predefined // Denotes a predefined type
+ NT_predefined, // Denotes a predefined type
+ NT_singleton // Denotes a singleton
};
class AstDeclaration